@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -66,7 +66,8 @@ public Q_SLOTS:
     void slotCheckSpelling();
     void slotSpeakText();
     void slotZoomReset();
-private Q_SLOTS:
+
+private:
     void slotUndoableClear();
     void slotSpellCheckerMisspelling(const QString &text, int pos);
     void slotSpellCheckerCorrected(const QString &, int, const QString &);
@@ -111,6 +112,8 @@ private:
     void deleteEndOfLine();
     void moveLineUpDown(bool moveUp);
     void moveCursorBeginUpDown(bool moveUp);
+    void regenerateColorScheme();
+    void updateReadOnlyColor();
     class PlainTextEditorPrivate;
     std::unique_ptr<PlainTextEditorPrivate> const d;
 };
